<?php
/**
 * medical-life functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package medical-life
 */
 require trailingslashit(get_template_directory()) .'wp_bootstrap_navwalker.php';
 require trailingslashit(get_template_directory()) .'/inc/medical-life-tgm-plugin-activation.php';
 /** 
  * # THEME DEFAULTS
  */
require get_template_directory() . '/inc/theme-defaults.php';
/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function medical_life_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'medical_life_content_width', 640 );
}
add_action( 'after_setup_theme', 'medical_life_content_width', 0 );
if ( ! function_exists( 'medical_life_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function medical_life_setup() {
	/*
	 * Make theme available for translation.
	 * If you're building a theme based on medical-life, use a find and replace
	 * to change 'medical-life' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'medical-life' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
    add_image_size('medical_life_service_title_desc',55,65,true);
    add_image_size('medical_life_healthtips_img',360,255,true);
    add_image_size('medical_life_specialist_img',252,255,true);
    add_image_size('medical_life_single_img',371,327,true);
	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'main-menu' => esc_html__( 'Main Menu', 'medical-life' ),
	) );
	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array('comment-form','comment-list','gallery','caption',) );
    add_theme_support( 'custom-logo', array(
           'height'      => 74,
           'width'       => 263,
           'flex-width'  => true,
           'header-text' => array( 'site-title', 'site-description' ),
        ));
	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'medical_life_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif;
add_action( 'after_setup_theme', 'medical_life_setup' );
/**
 * Registers an editor stylesheet for the theme.
 */
function medical_life_theme_add_editor_styles() {
    add_editor_style( 'editor-style.css' );
}
add_action( 'admin_init', 'medical_life_theme_add_editor_styles' );
/**
 * Enqueue scripts and styles.
 */
function medical_life_css_js_enqueue(){
    wp_enqueue_style( 'bootstrap', get_template_directory_uri().'/css/bootstrap.min.css',array(),'3.3.6','all' );
    wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/font-awesome.min.css',array(),'4.5.0','all' );
    wp_enqueue_style( 'medical-life-styles', get_template_directory_uri().'/css/style.css',array(),'','all' );
    wp_enqueue_style( 'medical-life-google-fonts-lato', 'http://fonts.googleapis.com/css?family=Lato', false );
    wp_enqueue_style( 'medical-life-google-openfont', 'http://fonts.googleapis.com/css?family=Open+Sans', false );
    wp_enqueue_style( 'medical-life-style', get_stylesheet_uri(),array(),'','all');
    wp_enqueue_style( 'medical-life-responsive', get_template_directory_uri().'/css/responsive.css',array(),'','all');  
    wp_enqueue_script( 'bootstrap',get_template_directory_uri().'/js/bootstrap.min.js', array('jquery'),'3.3.6',true);
    wp_enqueue_script( 'medical-life-skip-link-focus-fix', get_template_directory_uri() .'/js/skip-link-focus-fix.js', array(), '20151215', true );
   	wp_enqueue_script( 'medical-life-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );  
    wp_enqueue_script( 'medical-life-footer', get_template_directory_uri() . '/js/footer.js', array(), '', true );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action('wp_enqueue_scripts','medical_life_css_js_enqueue');
// enqueue css for customizer
function medical_life_customizer_css()
{
    wp_register_style('medical-life-customizer', trailingslashit(get_template_directory_uri()) . '/css/medical_life_customizer.css', false, '1.0.0' );
    wp_enqueue_style('medical-life-customizer');
}
add_action('customize_controls_enqueue_scripts','medical_life_customizer_css');
/**
 * Implement the Custom Header feature.
 */
require trailingslashit(get_template_directory()) . '/inc/custom-header.php';
// include the pro file
require_once( trailingslashit( get_template_directory() ) . 'medical-life-customize-pro/class-customize.php' );
/**
 * Customizer additions.
 */
require trailingslashit(get_template_directory()) . '/inc/customizer.php';
/**
 * for support link
 */
require trailingslashit(get_template_directory()).'/inc/medical-life-support.php';
// widgets
require get_template_directory() . '/inc/widgets.php';
/**
 * Setting excerpt length
 */
function medical_life_custom_excerpt_length( $length ) {
	           return 30;
}
// remove [.....] from excerpt content
add_filter( 'excerpt_length', 'medical_life_custom_excerpt_length', 999 );
function medical_life_new_excerpt_more( $more ) {
	return '&hellip;&hellip;';
}
add_filter('excerpt_more', 'medical_life_new_excerpt_more');
/************************************************/
/**
*To arrange the comment form field 
**/
add_filter( 'comment_form_fields', 'medical_life_move_comment_field' );
function medical_life_move_comment_field( $fields ) {
   $comment_field = $fields['comment'];
   unset( $fields['comment'] );
   $fields['comment'] = $comment_field;
   return $fields;
}
/********************* cusomizer function *****************************/
function medical_life_custom_logo(){
    if(function_exists('the_custom_logo')){
     the_custom_logo();
    }
}
/******* medical_life_get_option *****************/
/********************************************/
function medical_life_get_option($key){
    global $medical_life_defaults;
    if (array_key_exists($key, $medical_life_defaults)) 
        $value = get_theme_mod($key, $medical_life_defaults[$key]); 
    else
        $value = get_theme_mod($key);
    return $value;
}
/**
 * Include the TGM_Plugin_Activation class.
 */

add_action( 'tgmpa_register', 'medical_life_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 *  <snip />
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function medical_life_register_required_plugins() {
	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(
		array(
			'name'      => __('Contact Form 7','medical-life'),
			'slug'      => 'contact-form-7',
			'required'  => false,
		),
        array(
			'name'      => __('WordPress Importer','medical-life'),
			'slug'      => 'wordpress-importer',
			'required'  => false,
		),
           array(
			'name'      => __('Widget Importer & Exporter','medical-life'),
			'slug'      => 'widget-importer-exporter',
			'required'  => false,
		),
	);
	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'parent_slug'  => 'themes.php',            // Parent menu slug.
		'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);
	tgmpa( $plugins, $config );
}
add_action( 'wp_enqueue_scripts', 'medical_life_customize_css' );
function medical_life_customize_css() {
       if( is_home() || is_front_page() || is_page_template('Mhome.php')): 
       $simg= medical_life_get_option('medical_life_sliderImg');
       $custom_css  = "
            #medical-life-overlay{
                   background-image:url(". esc_url($simg)."); 
                   background-size:cover; 
            }";
         else:
              $custom_css=" 
               #medical-life-overlay{
                 background-image:url(".esc_url(medical_life_get_option('header_image'))."); 
                 background-size:cover; 
            }";
      endif;
        wp_add_inline_style( 'medical-life-style', $custom_css ,20);
}